package de.intevation.flys.exports;

import org.apache.log4j.Logger;

import org.jfree.data.xy.XYSeries;

import de.intevation.flys.artifacts.model.WKms; 
import de.intevation.flys.artifacts.model.WQKms; 

/**
 * Helper to create and modify StyledXYSeries.
 */
public class StyledSeriesBuilder {

    private static final Logger logger = Logger.getLogger(StyledSeriesBuilder.class);


    /**
     * Trivial, hidden constructor.
     */
    private StyledSeriesBuilder() {
    }


    /**
     * Add points to series.
     *
     * @param series Series to add points to.
     * @param points Points to add to series, points[0] to 1st dim, points[1]
     *               to 2nd dim.
     */
    public static void addPoints(XYSeries series, double[][] points) {
        double [] xPoints = points[0];
        double [] yPoints = points[1];
        for (int i = 0; i < xPoints.length; i++) {
            series.add(xPoints[i], yPoints[i], false);
        }
    }


    /**
     * Add points to series (km to 1st dim, w to 2nd dim).
     *
     * @param series Series to add points to.
     * @param points Points to add to series.
     */
    public static void addPoints(XYSeries series, WKms wkms) {
        int size = wkms.size();

        for (int i = 0; i < size; i++) {
            series.add(wkms.getKm(i), wkms.getW(i), false);
        }
    }


    /**
     * Add points to series (w to 1st dim, km to 2nd dim).
     *
     * @param series Series to add points to.
     * @param points Points to add to series.
     */
    public static void addPointsKmQ(XYSeries series, WQKms wqkms) {
       int size = wqkms.size();

       for (int i = 0; i < size; i++) {
           series.add(wqkms.getKm(i), wqkms.getQ(i), false);
       }
    }


    /**
     * Add points to series (q to 1st dim, w to 2nd dim).
     *
     * @param series Series to add points to.
     * @param points Points to add to series.
     */
    public static void addPointsQW(XYSeries series, WQKms wqkms) {
        int size = wqkms.size();

        for (int i = 0; i < size; i++) {
            series.add(wqkms.getQ(i), wqkms.getW(i));
        }
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
